.. _vectors:

Vectors and Vector Arrays
=========================

Vector Classes
--------------

.. autoclass:: bewegung.Vector2D
    :members:

.. autoclass:: bewegung.Vector2Ddist
    :members:

.. autoclass:: bewegung.Vector3D
    :members:

Vector Array Classes
--------------------

.. autoclass:: bewegung.VectorArray2D
    :members:

.. autoclass:: bewegung.VectorArray2Ddist
    :members:

.. autoclass:: bewegung.VectorArray3D
    :members:

The ``Matrix`` Class
--------------------

.. autoclass:: bewegung.Matrix
    :members:
